@@ -342,7 +342,7 @@ class fillVars(varsShare):
             localeVal = self.getValueFromConfig('/etc/env.d/02locale','LANG')
             if locale.isValueInFieldExists('locale',localeVal):
                 return localeVal
-        if os.environ.has_key("LANG"):
+        if os.environ.has_key("LANG") and os.environ["LANG"] != "C":
             return os.environ["LANG"]
         return locale.getFieldByLang("locale","default")
 
