@@ -73,9 +73,10 @@ def dialogYesNo(message, reYes=re.compile("^ye?s?$",re.I),
     """Вывод сообщения, ожидание набора Yes или No (в любом регистре)
 
     если Yes - True, если No - False"""
-    #sys.stdout.write(message + ": ")
+    sys.stdout.write(message + ": ")
+    sys.stdout.flush()
     #strIn=sys.stdin.readline().lower().strip()
-    strIn = raw_input(message + ": ")    
+    strIn = raw_input("")    
     sys.stdout.write("\n")
     if reYes.match(strIn):
         return True
