@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-__version__ = "2.2.11"
+__version__ = "2.2.12"
 __app__ = "calculate-lib"
 
 import sys, os, stat, re
@@ -356,10 +356,27 @@ class updateSystemConfigs(shareUpdateConfigs):
                 dstDir = os.path.dirname(dst)
                 self.createDir(configPath, dstDir)
                 copy2(src, dst)
-                sUid, sGid = getModeFile(src, mode="owner")
+                sMode, sUid, sGid = getModeFile(src)
                 os.chown(dst, sUid, sGid)
+                os.chmod(dst, sMode)
                 self.logger.warn(" "*5 + dst)
         return True
+    
+    def copyDirOrFile(self, src, dst, configPath):
+        if src != dst:
+            if os.path.isfile(src):
+                dstDir = os.path.dirname(dst)
+                self.createDir(configPath, dstDir)
+                copy2(src, dst)
+                sMode, sUid, sGid = getModeFile(src)
+                os.chown(dst, sUid, sGid)
+                os.chmod(dst, sMode)
+            elif os.path.isdir(src):
+                self.createDir(configPath, dst)
+                sMode, sUid, sGid = getModeFile(src)
+                os.chown(dst, sUid, sGid)
+                os.chmod(dst, sMode)
+                
 
     def updateConfig(self, nameProgram, category, version, configPath):
         """Обновление системных конфигурационных файлов"""
@@ -410,6 +427,12 @@ class updateSystemConfigs(shareUpdateConfigs):
                 for errMess in clTempl.getError().splitlines():
                     self.printERROR(errMess)
                 return False
+            copyFiles = clTempl.autoUpdateFiles
+            copyDirs = clTempl.autoUpdateDirs
+            allCopyAutoupdateFiles = copyDirs + copyFiles
+            for fileOrDir in allCopyAutoupdateFiles:
+                dst = "/" + fileOrDir.partition(configPath)[2]
+                self.copyDirOrFile(fileOrDir, dst, configPath)
             if dirsFiles and dirsFiles[1]:
                 if not nameAndVerPkg in listIndex:
                     listIndex.append(nameAndVerPkg)
